@@ -213,7 +213,8 @@ antcolony.lavaan = function(data = NULL, sample.cov = NULL, sample.nobs = NULL,
   if(!requireNamespace("lavaan", quietly = TRUE)){
     stop("The `lavaan` package is required to use this function. Please install `lavaan`, then try to use this function again.")
   }
-
+  fitmeasuresCheck(fit.indices)
+  fitStatTestCheck(fit.indices, fit.statistics.test)
   antcolony.lavaan.env <- new.env(parent = baseenv())
 
   if(pheromone.calculation %in% c("gamma", "beta", "regression", "variance") == FALSE) {
@@ -264,6 +265,7 @@ antcolony.lavaan = function(data = NULL, sample.cov = NULL, sample.nobs = NULL,
   step = 1
 
   # creates objects in the global environment that are fed into the lavaan function in order to fine-tune the model to user specifications
+  checkModelSpecs(lavaan.model.specs)
   mapply(assign, names(lavaan.model.specs), lavaan.model.specs, MoreArgs=list(envir = antcolony.lavaan.env))
 
   # create the function to check for and save error/warning messages within the lavaan output, as well as saving the fit indices
